<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Auction;
use App\Models\CancelMessages;
use App\Models\Notification;
use Carbon\Carbon;
use Illuminate\Http\Request;

class NotActiveAuctionsController extends Controller
{
    public function index()
    {
        $rows = Auction::where('status', '!=', 'active')->latest()->get();
        return view('admin.not_active_auctions.index', compact('rows'));
    }


    public function show($id)
    {
        $row = Auction::find($id);
        return view('admin.not_active_auctions.show', compact('row'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Auction::find($id);
        $cancel_messages = CancelMessages::all();

        return view('admin.not_active_auctions.edit', compact('row', 'cancel_messages'));
    }


    public function update(Request $request, $id)
    {
        $request->validate([
            'status' => 'required|in:active,not_active,cancel,waiting'
        ]);



        $auction = Auction::findOrFail($id);
        $auction->status = $request['status'];
        if ($request['cancel_message_text']) {
            $auction->cancel_message = $request['cancel_message_text'];

            $notification = new Notification();
            $notification['title->ar'] = "رساله من إدارة الموقع";
            $notification['title->en'] = "A message from the site administration";
            $notification['body->ar'] = $request['cancel_message_text'];
            $notification['body->en'] = $request['cancel_message_text'];
            $notification['type'] = 'admin';
            $notification['user_id'] = $auction->user_id;
            $notification['auction_id'] = $auction->id;
            $notification->save();

        }elseif ($request['cancel_message'] && $request['cancel_message_text'] == null){
            $cancelMessage = CancelMessages::findOrFail($request['cancel_message']);

            $auction->cancel_message = $cancelMessage->body;

            $notification = new Notification();
            $notification['title->ar'] = $cancelMessage->title;
            $notification['title->en'] = $cancelMessage->title;
            $notification['body->ar'] = $cancelMessage->body;
            $notification['body->en'] = $cancelMessage->body;
            $notification['type'] = 'admin';
            $notification['user_id'] = $auction->user_id;
            $notification['auction_id'] = $auction->id;
            $notification->save();
        }
        $auction->update();
        toast('تم التعديل بنجاح', 'success');

        return redirect()->route('notActiveAuctions.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Auction::destroy($id);
        toast('تمت العملية بنجاح', 'success');
    }

    public function not_active_auction_search(Request $request)
    {
        $request->validate([
            'from' => 'required',
            'to' => 'required'
        ]);
        $rows = Auction::where('status', '!=', 'active')->whereDate('created_at', '>=', Carbon::parse($request->from))->whereDate('created_at', '<=', Carbon::parse($request->to))->get();
        return view('admin.not_active_auctions.index', compact('rows'));
    }

}
