<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Http\Middleware\Lang;
use App\Models\Ad;
use App\Models\AdComment;
use App\Models\AdImage;
use App\Models\Auction;
use App\Models\City;
use App\Models\Favorite;
use App\Models\HarajCategory;
use App\Models\HarajType;
use App\Models\Messages;
use App\Models\Report;
use App\Models\Room;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class HarajProductsController extends Controller
{
    public function haraj_type()
    {
        $types = HarajType::all();
        return view('site.haraj.haraj_types', compact('types'));
    }

    public function pledge()
    {
        return view('site.haraj.haraj_terms');

    }

    public function save_type(Request $request)
    {
        \Session::put('type_id', $request['type_id']);
        return view('site.haraj.haraj_terms');
    }

    public function map()
    {
        return view('site.haraj.map');
    }

    public function select_location(Request $request)
    {
        $request->validate([
            'lat' => 'required',
            'lng' => 'required'
        ], [
            'lat.required' => trans('site.select_map'),
            'lng.required' => trans('site.select_map')
        ]);
        \Session::put('lat', $request['lat']);
        \Session::put('lng', $request['lng']);
        return view('site.haraj.upload_images');

    }

    public function accept_terms(Request $request)
    {
        $request->validate([
            'accept' => 'accepted'
        ], [
            'accept.accepted' => trans('site.accept_terms')
        ]);

        $cities = City::whereType('city')->get();

        return view('site.haraj.cities', compact('cities'));

    }

    public function area()
    {

        $areas = City::whereType('area')->get();

        return view('site.haraj.area', compact('areas'));

    }

    public function choose_area(Request $request)
    {
        $request->validate([
            'area_id' => 'required'
        ]);

        $area = City::find($request['area_id']);
        session()->put('farouz', 'mody');
        if (count($area->children) > 0) {
            $cities = City::whereParentId($request['area_id'])->get();

            return view('site.haraj.cities', compact('cities'));
        } else {
            \Session::put('city_id', $request['area_id']);
            return view('site.haraj.upload_images');
        }
    }

    public function choose_city(Request $request)
    {
        $request->validate([
          //  'city_id' => 'required'
        ]);

        $city = City::find($request['city_id']);
        session()->put('farouz', 'mody');
        // if (count($city->children) > 0) {
        //     $hays = City::whereParentId($request['city_id'])->get();
        //     return view('site.haraj.hays', compact('hays'));
        // } else {
           // \Session::put('city_id', $request['city_id']);
            return view('site.haraj.upload_images');
        //}
    }

    public function choose_hay(Request $request)
    {
        $request->validate([
            'hay_id' => 'required'
        ]);
        \Session::put('city_id', $request['hay_id']);
        return view('site.haraj.upload_images');

    }

    public function upload_images(Request $request)
    {
        $request->validate([
            'images' => 'required'
        ]);

        $images_array = [];
        $i = 1;

        foreach ($request['images'] as $image) {
            $filename = $i . '_' . time() . '.' . $image->getClientOriginalExtension();
            $image->move(public_path('images/harajs'), $filename);
            $images_array[] = $filename;
            $i++;
        }

        \Session::put('images', $images_array);

        return redirect()->route('add_advertisement');
    }

    public function add_advertisement()
    {
//        dd(session()->get('farouz'));
        $categories = HarajCategory::where('parent_id', null)->get();
        return view('site.haraj.add_advertisement', compact('categories'));
    }

    public function edit_ad($ad_id)
    {
        $ad = Ad::findOrFail($ad_id);
        if (\Auth::check() && $ad->user_id == \Auth::id()) {
            $categories = HarajCategory::where('parent_id', null)->get();

            $parent_category = HarajCategory::where(['id' => $ad->category_id, 'parent_id' => null])->first();
            $sub_categories = [];
            if ($parent_category == null) {
                $category = HarajCategory::find($ad->category_id);
                $parent_category = $category->parent;
            }
            $sub_categories = HarajCategory::whereParentId($parent_category->id)->get();


            return view('site.haraj.edit_ad', compact('ad', 'categories', 'parent_category', 'sub_categories'));
        } else {
            return redirect()->back();
        }

    }


    public function sub_categories(Request $request)
    {
        $sub_categories = HarajCategory::whereParentId($request['category_id'])->get();

        $main_category = HarajCategory::find($request['category_id']);
        $sub_categories_view = view('site.haraj.sub_categories', compact('sub_categories'))->render();
        return response()->json(['sub_categories' => $sub_categories_view, 'car' => $main_category->car_option == 'true' ? 'true' : 'false']);
    }

    public function check_car_option(Request $request)
    {

        $main_category = HarajCategory::find($request['category_id']);
        return response()->json(['car' => $main_category->car_option == 'true' ? 'true' : 'false']);
    }

    public function store_advertisement(Request $request)
    {
        if (session()->get('farouz') == null) {
            Alert::error(\Lang::get('site.pleaseEnterHarajFromTheBeginning'));
            return redirect()->route('pledge');
        }
        $request->validate([
            'title' => 'required',
            'description' => 'required',
            'mobile' => 'required',
            'pubg_show' => 'required|in:true,false',
            'price' => 'required',
            'pubg_email' => 'required_if:pubg_show,true',
            'pubg_password' => 'required_if:pubg_show,true'
        ]);


        $advertisement = new Ad();
        $advertisement['user_id'] = \Auth::user()->id;
        $advertisement['title'] = $request['title'];
        $advertisement['city_id'] = \Session::get('city_id');
        $advertisement['lat'] = \Session::get('lat');
        $advertisement['lng'] = \Session::get('lng');
        $advertisement['category_id'] = $request['category_id'] ? $request['category_id'] : $request['main_category_id'];
        $advertisement['year'] = $request['year'];
        $advertisement['description'] = $request['description'];
        $advertisement['car_type'] = $request['car_type'];
        $advertisement['price'] = $request['price'];
//        $advertisement['price_show'] = $request['price_show'];
        if ($request->pubg_show == 'true') {
            $advertisement['pubg_email'] = $request['pubg_email'];
            $advertisement['pubg_password'] = $request->pubg_password;
        }
        $advertisement['mobile'] = $request['mobile'];
        $advertisement['status'] = 'active';
        $advertisement['type_id'] = \Session::get('type_id');
        $advertisement->save();

        $code = "RJ0" . $advertisement->id;
        $advertisement->code = $code;
        $advertisement->update();


        $images_array = \Session::get('images');
        foreach ($images_array as $image) {
            AdImage::create([
                'image' => $image,
                'ad_id' => $advertisement->id
            ]);
        }

        \Session::forget('farouz');
//        \Session::forget('images');
//        \Session::forget('lat');
//        \Session::forget('lng');
//        \Session::forget('city_id');
        toast(trans('site.success_added'), 'success');
        return redirect()->route('advertisement_details', $advertisement->id);

    }

    public function advertisement_details($ad_id)
    {


        $ad = Ad::findOrFail($ad_id);


        $rows = Ad::whereCategoryId($ad->category_id)->get();

        return view('site.haraj.advertisement_details', compact('ad', 'rows'));

    }

    public function report($ad_id, Request $request)
    {
        $request->validate([
            'note' => 'required'
        ]);

        $request['user_id'] = \Auth::user()->id;
        $request['ad_id'] = $ad_id;
        Report::create($request->all());
        toast(trans('site.report_sent'), 'success');
        return redirect()->back();
    }

    public function report_comment($comment_id, Request $request)
    {
        $request->validate([
            'note' => 'required'
        ]);

        $request['user_id'] = \Auth::user()->id;
        $request['comment_id'] = $comment_id;
        Report::create($request->all());
        toast(trans('site.report_sent'), 'success');
        return redirect()->back();
    }

    public function delete_ad($ad_id)
    {

        Ad::destroy($ad_id);
        toast(trans('site.ad_deleted'), 'success');
        return redirect()->route('home');
    }

    public function send_speed_message($receiver_id, Request $request)
    {
        $request->validate([
            'message' => 'required'
        ]);
        $room_check = Room::where(['sender_id' => \Auth::user()->id, 'receiver_id' => $receiver_id])->orWhere(['sender_id' => $receiver_id, 'receiver_id' => \Auth::user()->id])->first();
        if (isset($room_check)) {
            $message = new Messages();
            $message['room_id'] = $room_check->id;
            $message['sender_id'] = \Auth::user()->id;
            $message['receiver_id'] = $receiver_id;
            $message['message'] = $request['message'];
            $message->save();
        } else {
            $room = Room::create([
                'name' => uniqid(),
                'sender_id' => \Auth::user()->id,
                'receiver_id' => $receiver_id,
                'status' => 'open',
            ]);

            $message = new Messages();
            $message['room_id'] = $room->id;
            $message['sender_id'] = \Auth::user()->id;
            $message['receiver_id'] = $receiver_id;
            $message['message'] = $request['message'];
            $message->save();
        }

        toast(trans('site.sent_success'), 'success');
        return redirect()->back();

    }

    public function comment(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'comment' => 'required',
            'ad_id' => 'required'
        ]);
        if ($validator->passes()) {
            $request['user_id'] = \Auth::user()->id;
            AdComment::create($request->all());
            toast(trans('site.commentAddedSuccessfully'), 'success');
            return back();
        } else {
            Alert::error($validator->errors()->first());
            return back();
        }
    }

    public function favourite_ad(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'ad_id' => 'required'
        ]);

        if (!\Auth::check()) return response()->json(['value' => 'false', 'msg' => trans('login_first')]);

        if ($validator->passes()) {

            $check = Favorite::where(['user_id' => \Auth::user()->id, 'ad_id' => $request['ad_id']])->first();
            if ($check) {
                $check->delete();
                $removed_class = 'fa-heart';
                $added_class = 'fa-heart-o';
                $message = trans('site.unfavoured');
                $count = getAdFavouriteCount($request['ad_id']);

            } else {

                Favorite::create(['user_id' => \Auth::user()->id, 'ad_id' => $request['ad_id']]);
                $removed_class = 'fa-heart-o';
                $added_class = 'fa-heart';
                $message = trans('site.liked');
                $count = getAdFavouriteCount($request['ad_id']);
            }

            return response()->json(['value' => 'true', 'data' => $message, 'removed_class' => $removed_class, 'count' => $count, 'added_class' => $added_class]);


        } else {
            return response()->json(['value' => 'false', 'msg' => $validator->errors()->first()]);
        }
    }

    public function get_harajs_parent(Request $request)
    {
        $ad_category_id = $request->category_id;
        if ($ad_category_id == 0) {
            $rows = Ad::where('status', 'active')->take(4)->get();
        } else {
            $categories = HarajCategory::where('parent_id', $ad_category_id)->pluck('id');
            $all_categories = $categories->merge($ad_category_id);
            $rows = Ad::where('status', 'active')->whereIn('category_id', $all_categories)->take(4)->get();
        }

        $view = view('site.controllers.product', compact('rows', 'ad_category_id'))->render();
        return response()->json(['html' => $view]);
    }

    public function get_harajs_child(Request $request)
    {
        $ad_category_id = $request->category_id;
        $rows = Ad::where(['status' => 'active', 'category_id' => $ad_category_id])->take(4)->get();
        $view = view('site.controllers.product', compact('rows', 'ad_category_id'))->render();
        return response()->json(['html' => $view]);
    }

    public function delete_image($id)
    {

        $image = AdImage::find($id);
        $ad = Ad::find($image->ad_id);
        if (count($ad->images) > 1) {
            AdImage::destroy($id);
            Alert::success(trans('site.deleted'));

        } else {
            Alert::error(trans('site.cant_delete_last_image'));
        }

        return redirect()->back();
    }

    public function update_ad($ad_id, Request $request)
    {
        $request->validate([
            'title' => 'required',
            'description' => 'required',
            'mobile' => 'required',
            'pubg_show' => 'required|in:true,false',
            'price' => 'required',
            'pubg_email' => 'required_if:pubg_show,true',
            'pubg_password' => 'required_if:pubg_show,true'
        ]);

        $advertisement = Ad::find($ad_id);
        $advertisement['title'] = $request['title'];
        $advertisement['category_id'] = $request['category_id'] ? $request['category_id'] : $request['main_category_id'];
        $advertisement['year'] = $request['year'];
        $advertisement['description'] = $request['description'];
        $advertisement['car_type'] = $request['car_type'];
        $advertisement['price'] = $request['price'];
//        $advertisement['price_show'] = $request['price_show'];
        if ($request->pubg_show == 'true') {
            $advertisement['pubg_email'] = $request['pubg_email'];
            $advertisement['pubg_password'] = $request->pubg_password;
        }
        $advertisement['mobile'] = $request['mobile'];
        $advertisement->update();

        if ($request['images']) {
            $i = 1;

            foreach ($request['images'] as $image) {
                $filename = $i . '_' . time() . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('images/harajs'), $filename);
                AdImage::create([
                    'image' => $filename,
                    'ad_id' => $advertisement->id
                ]);

                $i++;
            }
        }


        toast(trans('site.updated_success'), 'success');
        return redirect()->route('advertisement_details', $advertisement->id);

    }

    public function ad_more($id)
    {
        if ($id == 0) {
            $rows = Ad::where('status', 'active')->latest()->paginate(10);
        } else {
            $category = HarajCategory::find($id);
            if ($category->parent_id == null) {
                $categories = HarajCategory::where('parent_id', $id)->pluck('id');
                $all_categories = $categories->merge($id);
                $rows = Ad::where('status', 'active')->whereIn('category_id', $all_categories)->latest()->paginate(10);
            } else {
                $rows = Ad::where(['status' => 'active', 'category_id' => $id])->latest()->paginate(10);
            }
        }

        return view('site.haraj.harajs', compact('rows'));
    }

    public function search_haraj(Request $request)
    {
        $rows = Ad::where(['status' => 'active',
            ['title', '!=', null],
            [function ($query) use ($request) {
                if ($request->title) {
                    $query->where('title', 'LIKE', '%' . $request->title . '%');
                }
                if ($request->city_id) {
                    $city = City::find($request->city_id);
                    $hays = City::where('parent_id', $city->id)->pluck('id');
                    $area_city = [$city->id, $city->parent_id];
                    $all_cities = $hays->merge($area_city);
                    $query->whereIn('city_id', $all_cities);
                }
            }]
        ])->latest()->paginate(10);
        return view('site.haraj.harajs', compact('rows'));

    }

}
