<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Models\Ad;
use App\Models\Auction;
use App\Models\AuctionCategory;
use App\Models\City;
use App\Models\ContactUs;
use App\Models\HarajCategory;
use App\Models\Token;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;

class HomeController extends Controller
{

    public function home()
    {

        $cities = City::where('type', 'city')->get();
        $haraj_categories = HarajCategory::whereParentId(null)->get();
        $auction_categories = AuctionCategory::all();
        $now_auctions = Auction::whereStatus('active')->where('date', '<=', Carbon::now())->where('end_date', '>', Carbon::now())->take(4)->get();
        $last_auctions = Auction::whereStatus('active')->where('date', '<', Carbon::now()->subMinutes(30))->take(4)->get();
        $next_auctions = Auction::whereStatus('active')->where('date', '>', Carbon::now())->take(4)->get();
        $rows = Ad::whereStatus('active')->latest()->take(4)->get();
        return view('site.index', compact('haraj_categories', 'last_auctions', 'next_auctions', 'now_auctions', 'rows', 'auction_categories', 'cities'));
    }

    public function change_language_web($lang)
    {

        if ($lang == 'en' || $lang == 'ar') {
            if (!\Session::has('language')) {
                \Session::put('language', $lang);
            } else {
                \Session::put('language', $lang);
            }


            //  to get ar or en from url of change lang
            $lang = substr(\Request::path(), 9);
            // if ar replace en and put previous url
            if ($lang == "ar") {
                return redirect()->to(str_replace(url('/en'), '', url()->previous()));
            } else {
                return redirect()->to($lang . str_replace(url('/'), '', url()->previous()));
            }

        } else {
            return redirect('/');
        }
    }

    public function search_in_header(Request $request)
    {
        $searchQuery = '%' . $request->title . '%';
    
        $rows = Ad::where('status', 'active')
            ->whereNotNull('title')
            ->where(function ($query) use ($searchQuery, $request) {
                $query->where('title', 'LIKE', $searchQuery)
                    ->orWhere('code', 'LIKE', $searchQuery)
                    ->orWhereHas('category', function ($q) use ($request) {
                        $q->whereJsonContains('name->ar', $request->title);
                        $q->whereJsonContains('name->en', $request->title);
                    });
            })
            ->latest()
            ->paginate(10);
    
        $auctions = Auction::where('status', 'active')
            ->whereNotNull('title')
            ->where(function ($query) use ($searchQuery, $request) {
                $query->where('title', 'LIKE', $searchQuery)
                    ->orWhere('code', 'LIKE', $searchQuery)
                    ->orWhereHas('category', function ($q) use ($request) {
                        $q->whereJsonContains('name->ar', $request->title);
                        $q->whereJsonContains('name->en', $request->title);
                    });
            })
            ->latest()
            ->paginate(10);
    
        return view('site.users.favorites', compact('rows', 'auctions'));
    }

    public function saveToken(Request $request)
    {


        $check = Token::whereDeviceToken($request->token);
        if (!$check) {
            Token::create([
                'device_token' => $request->token
            ]);
        }

        return response()->json(['token saved successfully.']);
    }

    public function termsAndPolicy()
    {

        return view('site.pages.termsAndPolicy');
    }

    public function policy()
    {

        return view('site.pages.policy');
    }

    public function banned_products()
    {
        return view('site.pages.banned_products');
    }

    public function security_policies()
    {
        return view('site.pages.security_policies');
    }

    public function common_questions()
    {
        return view('site.pages.common_questions');
    }

    public function contact_us()
    {
        return view('site.pages.contact_us');
    }

    public function contactUs(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'mobile' => 'required',
            'email' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);
        ContactUs::create($request->all());
        toast(\Lang::get('site.sent_success'));
        return redirect()->back();
    }

    public function userProfile($user_id)
    {
        $user = User::findOrFail($user_id);
        $waiting_auctions = $user->auctions()->whereStatus('waiting')->take(4)->get();
        $now_auctions = $user->auctions()->where('date', '<=', Carbon::now())->where('end_date', '>', Carbon::now())->latest()->take(4)->get();
        $last_auctions = $user->auctions()->whereStatus('active')->where('date', '<', Carbon::now()->subMinutes(30))->take(4)->get();
        $next_auctions = $user->auctions()->whereStatus('active')->where('date', '>', Carbon::now())->take(4)->get();
        $rows = $user->ads()->whereStatus('active')->latest()->take(4)->get();

        return view('site.users.userProfile', compact('rows', 'now_auctions', 'user', 'waiting_auctions', 'next_auctions', 'last_auctions'));
    }
}
