<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\Auth;

class User extends Authenticatable
{
    use HasFactory, Notifiable;

    protected $table = 'users';
    public $timestamps = true;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = array('username', 'block', 'mobile', 'email', 'code', 'password', 'verified', 'status', 'last_online', 'image', 'registrationId', 'payment_method', 'bank_account', 'bank_name', 'country_code', 'iban_number', 'bank_name');


    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function ads()
    {
        return $this->hasMany(Ad::class, 'user_id');
    }

    public function orders()
    {
        return $this->hasMany(AdOrder::class, 'user_id');
    }

    public function auctions()
    {
        return $this->hasMany(Auction::class, 'user_id');
    }

    public function winner_auctions()
    {
        return $this->hasMany(Auction::class, 'winner_id');
    }

    public function favourite_ads()
    {
        return $this->belongsToMany(Ad::class, 'favorites', 'user_id', 'ad_id');
    }

    public function favourite_auctions()
    {
        return $this->belongsToMany(Auction::class, 'favorites', 'user_id', 'auction_id');
    }

    public function subscription_auctions()
    {
        return $this->belongsToMany(Auction::class, 'auction_subscriptions', 'user_id', 'auction_id');
    }

    public function user_credit()
    {
        return $this->hasOne(UserCredit::class, 'user_id');
    }

    public function notifications()
    {
        return $this->hasMany(Notification::class, 'user_id');
    }

    public function harajs()
    {
        return $this->hasMany(Ad::class, 'user_id');
    }

    public function setImageAttribute()
    {
        $file = request()->file('image');
        $destinationPath = 'images/users/';
        $filename = md5(rand('11', '99')) . '.' . $file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['image'] = $filename;
    }

    public function getImageAttribute()
    {

        if (isset($this->attributes['image'])) {
            return asset('images/users/') . '/' . $this->attributes['image'];
        }
        return asset('logo.png');
    }
}
